about summary refs log tree commit diff
path: root/pkgs/games/0ad
diff options
context:
space:
mode:
Diffstat (limited to 'pkgs/games/0ad')
-rw-r--r--pkgs/games/0ad/game.nix6
1 files changed, 3 insertions, 3 deletions
diff --git a/pkgs/games/0ad/game.nix b/pkgs/games/0ad/game.nix
index f98fbdf298cd5..ae0b2180a80fd 100644
--- a/pkgs/games/0ad/game.nix
+++ b/pkgs/games/0ad/game.nix
@@ -47,9 +47,9 @@ stdenv.mkDerivation rec {
     # Delete shipped libraries which we don't need.
     rm -rf libraries/source/{enet,miniupnpc,nvtt,spidermonkey}
 
-    # Workaround invalid pkgconfig name for mozjs
-    mkdir pkgconfig
-    ln -s ${spidermonkey_38}/lib/pkgconfig/* pkgconfig/mozjs-38.pc
+    # Workaround invalid pkg-config name for mozjs
+    mkdir pkg-config
+    ln -s ${spidermonkey_38}/lib/pkgconfig/* pkg-config/mozjs-38.pc
     PKG_CONFIG_PATH="$PWD/pkgconfig:$PKG_CONFIG_PATH"
 
     # Update Makefiles